COLORS = {
    'PROBLEM': 'red',
    'RECOVERY': 'green',
    'ACKNOWLEDGEMENT': 'purple',
    'FLAPPINGSTART': 'yellow',
    'WARNING': 'yellow',
    'UNKNOWN': 'gray',
    'CRITICAL': 'red',
    'FLAPPINGSTOP': 'green',
    'FLAPPINGDISABLED': 'purple',
    'DOWNTIMESTART': 'red',
    'DOWNTIMESTOP': 'green'
}
